@@ -13,10 +13,10 @@ th.cyc <-
     # Before runing the analysis, test if signal is indeed larger than the 
     # threshold.
     
-    if (quantile(xy[, 2], 0.9) <= r) {
-      # TODO: FIX OUTPUT
-      stop("Maximum of signal lower than threshold (r).")
-    } else {
+#     if (quantile(xy[, 2], 0.9) <= r) {
+#       # TODO: FIX OUTPUT
+#       stop("Maximum of signal lower than threshold (r).")
+#     } else {
       # Actually used number of neighbours around the threshold value
       n <- seq(2, 8, 1)
       
@@ -64,7 +64,7 @@ th.cyc <-
       new("th", .Data = res, 
           stats = xy.sum[["summary"]], 
           input = data.matrix(xy.sum[["values"]]))
-    }
+#     }
   }
 
 
